#!/bin/bash
# Server installation script for 
# Ready_™ on Debian Buster 11
#
# @version 1.0.1 for Debian Bullseye Version PHP 7.4, PostgreSQL 15
# @author: eDokumenty sp z o.o.
# @modified Jarosław Połczyński, jpolczynski@edokumenty.eu
#
# Instrukacja instalcji znajduje się pod wskazanym linkiem https://support.edokumenty.eu/trac/wiki/AdminGuide/DebianInstaller

INSTALL_DIR=$(pwd)

echo -ne "\033[01;32mCzy chcesz instalowac pakiety managerem apt-get? Zalecane y (y/n) \033[00m \n"
read APTYESNO
if [ "$APTYESNO" = "y" ]; then

#gnupg
apt-get -y install gnupg

echo -e "\033[01;34mDodanie repozytorium dla PostgreSQL 15 \033[00m"
wget --quiet -O - https://www.postgresql.org/media/keys/ACCC4CF8.asc | apt-key add -
echo "deb http://apt.postgresql.org/pub/repos/apt/ bullseye"-pgdg main | tee  /etc/apt/sources.list.d/pgdg.list
sleep 2

echo -e "\033[01;34mDodanie repozytorium dla PHP 7.4 \033[00m"
apt -y install ca-certificates apt-transport-https 
wget -q https://packages.sury.org/php/apt.gpg -O- | apt-key add -
echo "deb https://packages.sury.org/php/ bullseye main" |  tee /etc/apt/sources.list.d/php.list
sleep 1

echo -e "\033[01;34mOdświeżenie repozytoriów \033[00m"
apt-get update

echo -e "\033[01;34mInstalowanie pakietów podstawowych \033[00m"
# Base tools
apt-get -y install ssh
apt-get -y install mc
apt-get -y install nmap
apt-get -y install ngrep
apt-get -y install sed
apt-get -y install wget
apt-get -y install gzip
apt-get -y install adduser
apt-get -y install bzip2
apt-get -y install unzip
apt-get -y install rsync
apt-get -y install less
apt-get -y install rdate
apt-get -y install vim
apt-get -y install zip

echo -e "\033[01;34mInstalowanie pakietów systemowych \033[00m"
# System tools
apt-get -y install sudo
apt-get -y install cron
apt-get -y install iproute2
apt-get -y install tcpdump
apt-get -y install ntp 
apt-get -y install htop
apt-get -y install iotop
apt-get -y install iostat

echo -e "\033[01;34mInstalowanie dodatkowych pakietów \033[00m"
# Additional tools
apt-get -y install apt-show-versions
apt-get -y install gcc
apt-get -y install g++
apt-get -y install cpp
apt-get -y install make
apt-get -y install curl

# Processing tools
apt-get -y install imagemagick
apt-get -y install html2ps
apt-get -y install latex2rtf
apt-get -y install antiword
apt-get -y install gnuhtml2latex
apt-get -y install tesseract-ocr
apt-get -y install tesseract-ocr-pol

echo -e "\033[01;34mInstalowanie pakietów Apache2, PHP 7.4, PostgreSQL 15 \033[00m"
# Services Apache, PHP, PostgreSQL15
apt-get -y install postgresql-15
apt-get -y install apache2
apt -y install libapache2-mod-security2
apt-get -y install php7.4-fpm 
apt-get -y install php7.4-cli 
apt-get -y install php7.4-common 
apt-get -y install php7.4-curl 
apt-get -y install php7.4-mbstring 
apt-get -y install php7.4-mysql 
apt-get -y install php7.4-xml 
apt-get -y install php7.4-gd 
apt-get -y install php7.4-pgsql 
apt-get -y install php7.4-bcmath 
apt-get -y install php7.4-sqlite3 
apt-get -y install php7.4-imap 
apt-get -y install php7.4-xsl 
apt-get -y install php7.4-ldap 
apt-get -y install php7.4-odbc 
apt-get -y install php7.4-json 
apt-get -y install php7.4-sybase 
apt-get -y install php7.4-readline 
apt-get -y install php7.4-soap
apt-get -y install php7.4-zip
apt-get -y install php7.4-redis

echo -e "\033[01;34mInstalowanie pakietów Redis-Server \033[00m"
apt-get -y install redis-server

apt-get -y install subversion
apt-get -y install openssl
apt-get -y install ssl-cert
apt-get -y install abiword
apt-get -y install hdparm

fi


# Instalacja pgbouncer + config
echo -ne "\033[01;32mCzy zainstalowac Pgbouncer? (y/n) \033[00m \n"
read PGBOUNCER
if [ "$PGBOUNCER" = "y" ]; then
    apt-get -y install pgbouncer
fi


echo -e "\033[01;34mZakladanie kont i konfiguracja grup dla użytkownika edokumenty \033[00m"
# konta i grupy systemowe dla usera edokumenty
/usr/sbin/adduser --gecos  "" --ingroup users edokumenty
/usr/sbin/groupadd edokumenty
/usr/sbin/adduser edokumenty edokumenty
/usr/sbin/adduser www-data edokumenty


echo -e "\033[01;34mZakladanie kont i konfiguracja grup dla użytkownika test \033[00m"
# konta i grupy systemowe dla usera test
/usr/sbin/adduser --gecos  "" --ingroup users test
/usr/sbin/groupadd test


echo -e "\033[01;34mAktywacja modulow Apache2 \033[00m"
for module in ssl rewrite userdir vhost_alias actions alias proxy_fcgi headers security2
do 
   /usr/sbin/a2enmod $module;
done

#enable ssl
/usr/sbin/a2ensite default-ssl


# Kopia plikow konfiguracyjnych
echo -ne "\033[01;32mCzy wykonać kopię plików konfiguracyjnych (y/n) \033[00m \n"
read BACKUPCONF
if [ "$BACKUPCONF" = "y" ]; then
    ./bin/backup_conf_client.sh
fi

# Modyfikacje plików konfiguracyjnych
echo -ne "\033[01;32mCzy modyfikowac pliki konfiguracyjne (zalecane y)? (y/n) \033[00m \n"
read CONFYESNO
if [ "$CONFYESNO" = "y" ]; then
echo -e "\033[01;34mModyfikacja plików konfiguracyjnych Apache2 \033[00m"
	# Zmiana konfiguracji hostow Apache
    rm -f /etc/apache2/sites-available/*
    cp -p $INSTALL_DIR'/conf/etc/apache2/sites-available/000-default.conf' /etc/apache2/sites-available/
    cp -p $INSTALL_DIR'/conf/etc/apache2/sites-available/default-ssl.conf' /etc/apache2/sites-available/
	  cp -p $INSTALL_DIR'/conf/etc/apache2/sites-enabled/test.conf' /etc/apache2/sites-enabled/
    cp -p $INSTALL_DIR'/conf/etc/apache2/apache2.conf' /etc/apache2/
	  cp -p $INSTALL_DIR'/conf/etc/apache2/conf-available/security.conf' /etc/apache2/conf-available/
	  cp -p $INSTALL_DIR'/conf/etc/apache2/mods-available/ssl.conf' /etc/apache2/mods-available/


echo -e "\033[01;34mDostarczenie certyfiaktu dla localhost \033[00m"
   # Kopiowanie testowego certyfiaktu dla SSL
    cp -p $INSTALL_DIR'/conf/etc/ssl/edokumenty.pem' /etc/ssl/private/
    cp -p $INSTALL_DIR'/conf/etc/ssl/edokumenty.key' /etc/ssl/private/

echo -e "\033[01;34mModyfikacja plików konfiguracyjnych PHP-FPM \033[00m"
    # Konfiguracja PHP/FPM
    cp -p $INSTALL_DIR'/conf/etc/php/7.4/cli/php.ini' /etc/php/7.4/cli/
	  cp -p $INSTALL_DIR'/conf/etc/php/7.4/fpm/php.ini' /etc/php/7.4/fpm/
	  cp -p $INSTALL_DIR'/conf/etc/php/7.4/fpm/pool.d/www.conf' /etc/php/7.4/fpm/pool.d/
	  cp -p $INSTALL_DIR'/conf/etc/php/7.4/mods-available/bsedt.ini' /etc/php/7.4/mods-available/

echo -e "\033[01;34mModyfikacja plików konfiguracyjnych Redis \033[00m"	
	  #Konfiguracja php-redis
    cp -p $INSTALL_DIR'/conf/etc/redis/redis.conf' /etc/redis/


echo -e "\033[01;34mModyfikacja plików konfiguracyjnych pgBouncer \033[00m"
	#Konfiguracja pgbouncer
    cp -p $INSTALL_DIR'/conf/etc/pgbouncer/pgbouncer.ini' /etc/pgbouncer
    cp -p $INSTALL_DIR'/conf/etc/pgbouncer/userlist.txt' /etc/pgbouncer

echo -e "\033[01;34mModyfikacja plików konfiguracyjnych PostgreSQL 15 - pg_hba.conf \033[00m"
	  cp -p $INSTALL_DIR'/conf/etc/postgresql/15/main/pg_hba.conf' /etc/postgresql/15/main

echo -e "\033[01;34mTworzenie symlinkow dla pakietu bsedt \033[00m"	
	# Tworzenie linku symbolicznego do modulu bsedt
	ln -s /etc/php/7.4/mods-available/bsedt.ini /etc/php/7.4/cli/conf.d/bsedt.ini
	ln -s /etc/php/7.4/mods-available/bsedt.ini /etc/php/7.4/fpm/conf.d/bsedt.ini
 
echo -e "\033[01;34mWyłączenie opcache \033[00m" 
	#Modyfikacja OPCACHE
	vim -c '%s/zend_extension=opcache.so/;zend_extension=opcache.so/' -c 'wq' /etc/php/7.4/mods-available/opcache.ini

  #Utworzene oraz nadanie uprawnień dla pliku php_error.log
  touch /var/log/php_error.log
  chown www-data:www-data /var/log/php_error.log

fi

echo -e "\033[01;34mPoprawa uprawnień do plików konfiguracyjnych \033[00m"
./bin/sys_perms.sh

echo -e "\033[01;34mUtworzenie public_html i pozostałych podkatalogów. Nadanie uprawenień do odczytu i zapisu \033[00m"
./bin/create_edok_dirs.sh

echo -e "\033[01;34mDodanie ramdisk w fstab dla usługi backproc \033[00m"
./bin/fstab.sh

# Instalacja IONCuber Loader
echo -ne "\033[01;32mCzy chcesz instalowac modul IONCube Loader dla PHP 7.4? (y/n) \033[00m \n"
read CONFYESNO
if [ "$CONFYESNO" = "y" ]; then
    echo -e "\033[01;34mInstalacja IONCube Loader dla PHP 7.4 \033[00m"
    cp   $INSTALL_DIR'/conf/usr/lib/php/ioncube_loader_lin_7.4.so' /usr/lib/php/
fi


echo -e "\033[01;34mInstalacja modulu bsedt - tłumaczenia \033[00m"
	cp   $INSTALL_DIR'/conf/usr/lib/php/20190902/bsedt.so' /usr/lib/php/20190902/


# Tworzenie użytkowników bazy danych (wszyscy z opcjami N)
echo -e "\033[01;34mTworzenie uzytkownika bazy danych - http (wszystkie opcje N) \033[00m"
sudo -u postgres createuser --no-superuser --no-createdb --no-createrole http
echo -e "\033[01;34mTworzenie uzytkownika bazy danych - edokumenty (wszystkie opcje N) \033[00m"
sudo -u postgres createuser --no-superuser --no-createdb --no-createrole edokumenty


# Tworzenie baz danych
echo -e "\033[01;34mTworzenie pustej bazy edokumenty \033[00m"
sudo -u postgres createdb -E UTF8 edokumenty -O edokumenty



echo -e "\033[01;34mKonfiguracja domyslnego backupu - domyslne skrypty, ustawienia backapu i skrypty crona \033[00m"
./bin/backup_dirs.sh

cd $INSTALL_DIR
  cp -p $INSTALL_DIR'/lib/backup/backup_db.sh' /etc/backup/
  cp -p $INSTALL_DIR'/lib/backup/backup_repos.sh' /etc/backup/
  cp -p $INSTALL_DIR'/lib/backup/backup_files.sh' /etc/backup/
  cp -p $INSTALL_DIR'/lib/backup/backup_publichtml.sh' /etc/backup/
  cp -p $INSTALL_DIR'/lib/backup/backup_repository.sh' /etc/backup/
  cp -p $INSTALL_DIR'/lib/backup/clear_edok_var.sh' /etc/backup/
  cp -p $INSTALL_DIR'/lib/backup/maildrop_clear.sh' /etc/backup/
  cp -p $INSTALL_DIR'/lib/backup/update_test.sh' /etc/backup/

  chmod 755 /etc/backup/*

  cp -p $INSTALL_DIR'/lib/backup/exclude_test.conf' /etc/backup

  cp -p $INSTALL_DIR'/lib/backup/edokumenty' /etc/cron.d/

# Restart Apache i Postgres
echo -e "\033[01;34mRestart Apache \033[00m"
sleep 2
/etc/init.d/apache2 restart

echo -e "\033[01;34mRestart PHP 7.4 FMP \033[00m"
sleep 2
/etc/init.d/php7.4-fpm restart

echo -e "\033[01;34mRestart PostgreSQL \033[00m"
sleep 2
/etc/init.d/postgresql restart


echo -e "\033[01;34mFileIndexingTool - tworzenie katalogow oraz przenoszenie skryptow \033[00m"

  cp $INSTALL_DIR'/lib/FileIndexingTool/Run.inc'  /home/edokumenty/public_html/apps/edokumenty/scripts/FileIndexingTool/
  cp $INSTALL_DIR'/lib/FileIndexingTool/FileIndex.inc'  /home/edokumenty/public_html/apps/edokumenty/scripts/FileIndexingTool/
  cp $INSTALL_DIR'/lib/FileIndexingTool/FileIndexLog.inc'  /home/edokumenty/public_html/apps/edokumenty/scripts/FileIndexingTool/
  cp $INSTALL_DIR'/lib/FileIndexingTool/FileIndexStatus.inc'  /home/edokumenty/public_html/apps/edokumenty/scripts/FileIndexingTool/
  cp $INSTALL_DIR'/lib/FileIndexingTool/conf/config.json'  /home/edokumenty/public_html/apps/edokumenty/scripts/FileIndexingTool/conf/

echo -e "\033[01;34mDodanie wpisow do systemowego crona \033[00m"
./bin/cron.sh

echo -ne "\033[01;32mInstalacja pakietów dodatkowych OCR? (y/n) \033[00m \n"
read CONFYESNO
if [ "$CONFYESNO" = "y" ]; then
    echo -e "\033[01;34mInstalacja pakietów Tesseract \033[00m"
    ./bin/ocr_packet.sh
fi

echo -ne "\033[01;32mInstalacja dla Generowanie podglądu plików do PDF? (y/n) \033[00m \n"
read CONFYESNO
if [ "$CONFYESNO" = "y" ]; then
    echo -e "\033[01;34mInstalacja dla Generowanie podglądu plików do PDF \033[00m"
    ./bin/libreoffice.sh
fi

echo -e "\033[01;32mKoniec pracy instalatora \033[00m"